@@ -225,6 +225,7 @@ def pie_chart(data, opts=None):
     parse_option(opts, "label_distance", 0.6)
     parse_option(opts, "max_label_length", None)
     parse_option(opts, "max_label_sep", "...")
+    parse_option(opts, "border", None)
     
     # Make a copy of the data (since it can be changed)
     data = data.copy()
@@ -297,8 +298,13 @@ def pie_chart(data, opts=None):
             opts["title"] += f" ({value_format(tot, opts['value_format'])})"
         plt.title(opts["title"], fontweight="bold", fontsize=opts["title_fontsize"], y=1.04)
     
+    # Border
+    wp = None
+    if opts["border"] is not None:
+        wp = {"edgecolor": opts["border"][0], "linewidth": opts["border"][1]}
+        
     # Generate pie
-    plt.pie(vals, labels=labels, explode=expl, autopct=make_autopct(vals), pctdistance=opts["label_distance"], shadow=opts["shadow"], startangle=opts["angle"], colors=fix_cmap(opts["cmap"], vals), textprops={"color": opts["label_color"]})
+    plt.pie(vals, labels=labels, explode=expl, autopct=make_autopct(vals), pctdistance=opts["label_distance"], shadow=opts["shadow"], startangle=opts["angle"], colors=fix_cmap(opts["cmap"], vals), textprops={"color": opts["label_color"]}, wedgeprops=wp)
     
     plt.tight_layout()
     
@@ -532,6 +538,7 @@ def generate_labels(fmt, n):
                 sy += 1
         return labels
 
+
 #
 # Generates a line chart from a dict or list.
 #
@@ -616,3 +623,94 @@ def line_chart(data, opts=None):
     # Show it!
     plt.show()
     plt.close()
+    
+
+#
+# Generates multiple line charts a list of dicts or lists.
+#
+def multi_line_chart(data, opts=None):
+    # Check params  
+    if not valid(data, [list, np.ndarray]): return
+    if opts is None:
+        opts = {}
+    if not valid(opts, [dict]): return
+    
+    # Parse options
+    parse_option(opts, "size", (14,6))
+    parse_option(opts, "fontsize", 14)
+    parse_option(opts, "title_fontsize", 18)
+    parse_option(opts, "font", "Arial")
+    parse_option(opts, "title", None)
+    parse_option(opts, "value_format", "")
+    parse_option(opts, "label_rotation", 0)
+    parse_option(opts, "y_label", None)
+    parse_option(opts, "y_label_color", "#244a6e")
+    parse_option(opts, "y_lim", None)
+    parse_option(opts, "x_label", None)
+    parse_option(opts, "x_label_color", "#244a6e")
+    parse_option(opts, "grid", False)
+    parse_option(opts, "labels", "range 0")
+    parse_option(opts, "labels_fontsize", 12)
+    parse_option(opts, "legend", None)
+    parse_option(opts, "trend", False)
+    parse_option(opts, "cmap", "Paired")
+    
+    # Plot settings
+    plt.rcParams.update({"font.size": opts["fontsize"]})
+    plt.rcParams.update({"font.family": opts["font"]})
+    plt.figure(figsize=opts["size"])
+    plt.tight_layout()
+    
+    plt.xticks(fontsize=opts["labels_fontsize"], rotation=opts["label_rotation"])
+    
+    # Title
+    if opts["title"] is not None:
+        plt.title(opts["title"], fontweight="bold", fontsize=opts["title_fontsize"], y=1.04)
+    
+    # Convert values
+    colors=fix_cmap(opts["cmap"], range(0,len(data)))
+    for e,col in zip(data,colors):
+        if type(e) == dict:
+            vals = list(e.values())
+            labels = list(e.keys())
+        else:
+            vals = e
+            labels = generate_labels(opts["labels"], len(vals))
+
+        # Generate line
+        if labels is not None:
+            plt.plot(labels, vals, color=col, linewidth=2)
+        else:
+            plt.plot(vals, color=col, linewidth=2)
+                    
+        # Trend line
+        if opts["trend"]:
+            p = np.poly1d(np.polyfit(range(0,len(vals)), vals, 1))
+            trend = [p(x) for x in range(0,len(vals))]
+            plt.plot(trend, color=col, linestyle="--", linewidth=1)
+    
+    if opts["legend"] is not None:
+        plt.gca().legend(opts["legend"])
+    
+    # Grid
+    if opts["grid"]:
+        plt.grid(axis="y", color ="grey", linewidth=0.5, alpha=0.2)
+    
+    # Axis labels
+    if opts["y_label"] is not None:
+        plt.ylabel(opts["y_label"], color=opts["y_label_color"], fontweight="bold")
+    if opts["x_label"] is not None:
+        plt.xlabel(opts["x_label"], color=opts["x_label_color"], fontweight="bold")
+    
+    # Set y-label format to prefix
+    if opts["value_format"].startswith("prefix"):
+        def label_formatter(x, pos):
+            return value_format(int(x), opts["value_format"])
+        plt.gca().yaxis.set_major_formatter(plt.matplotlib.ticker.FuncFormatter(label_formatter))
+    
+    if opts["y_lim"] is not None:
+        plt.ylim(opts["y_lim"])
+    
+    # Show it!
+    plt.show()
+    plt.close()
